@@ -1,4 +1,4 @@
-# flake8: NOQA
+"""libtmux, a typed, pythonic API wrapper for the tmux terminal multiplexer."""
 from .__about__ import (
     __author__,
     __copyright__,
