@@ -6,7 +6,7 @@ libtmux.session
 """
 import dataclasses
 import logging
-import os
+import pathlib
 import typing as t
 import warnings
 
@@ -36,8 +36,7 @@ logger = logging.getLogger(__name__)
 
 @dataclasses.dataclass()
 class Session(Obj, EnvironmentMixin):
-    """
-    A :term:`tmux(1)` :term:`Session` [session_manual]_.
+    """:term:`tmux(1)` :term:`Session` [session_manual]_.
 
     Holds :class:`Window` objects.
 
@@ -75,13 +74,17 @@ class Session(Obj, EnvironmentMixin):
     server: "Server"
 
     def refresh(self) -> None:
+        """Refresh session attributes from tmux."""
         assert isinstance(self.session_id, str)
         return super()._refresh(
-            obj_key="session_id", obj_id=self.session_id, list_cmd="list-sessions"
+            obj_key="session_id",
+            obj_id=self.session_id,
+            list_cmd="list-sessions",
         )
 
     @classmethod
     def from_session_id(cls, server: "Server", session_id: str) -> "Session":
+        """Create Session from existing session_id."""
         session = fetch_obj(
             obj_key="session_id",
             obj_id=session_id,
@@ -94,40 +97,42 @@ class Session(Obj, EnvironmentMixin):
     # Relations
     #
     @property
-    def windows(self) -> QueryList["Window"]:  # type:ignore
-        """Windows belonging session.
+    def windows(self) -> QueryList["Window"]:
+        """Windows contained by session.
 
         Can be accessed via
         :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.windows.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        windows: t.List["Window"] = []
-        for obj in fetch_objs(
-            list_cmd="list-windows",
-            list_extra_args=["-t", str(self.session_id)],
-            server=self.server,
-        ):
-            if obj.get("session_id") == self.session_id:
-                windows.append(Window(server=self.server, **obj))
+        windows: t.List["Window"] = [
+            Window(server=self.server, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-windows",
+                list_extra_args=["-t", str(self.session_id)],
+                server=self.server,
+            )
+            if obj.get("session_id") == self.session_id
+        ]
 
         return QueryList(windows)
 
     @property
-    def panes(self) -> QueryList["Pane"]:  # type:ignore
-        """Panes belonging session.
+    def panes(self) -> QueryList["Pane"]:
+        """Panes contained by session's windows.
 
         Can be accessed via
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        panes: t.List["Pane"] = []
-        for obj in fetch_objs(
-            list_cmd="list-panes",
-            list_extra_args=["-s", "-t", str(self.session_id)],
-            server=self.server,
-        ):
-            if obj.get("session_id") == self.session_id:
-                panes.append(Pane(server=self.server, **obj))
+        panes: t.List["Pane"] = [
+            Pane(server=self.server, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-panes",
+                list_extra_args=["-s", "-t", str(self.session_id)],
+                server=self.server,
+            )
+            if obj.get("session_id") == self.session_id
+        ]
 
         return QueryList(panes)
 
@@ -135,8 +140,7 @@ class Session(Obj, EnvironmentMixin):
     # Command
     #
     def cmd(self, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """
-        Return :meth:`server.cmd`.
+        """Execute tmux subcommand against target session. See :meth:`server.cmd`.
 
         Returns
         -------
@@ -151,7 +155,7 @@ class Session(Obj, EnvironmentMixin):
         # if -t is not set in any arg yet
         if not any("-t" in str(x) for x in args):
             # insert -t immediately after 1st arg, as per tmux format
-            new_args: t.Tuple[str, ...] = tuple()
+            new_args: t.Tuple[str, ...] = ()
             new_args += (args[0],)
             assert isinstance(self.session_id, str)
             new_args += (
@@ -162,14 +166,17 @@ class Session(Obj, EnvironmentMixin):
             args = new_args
         return self.server.cmd(*args, **kwargs)
 
-    #
-    # Commands (tmux-like)
-    #
+    """
+    Commands (tmux-like)
+    """
+
     def set_option(
-        self, option: str, value: t.Union[str, int], _global: bool = False
+        self,
+        option: str,
+        value: t.Union[str, int],
+        _global: bool = False,
     ) -> "Session":
-        """
-        Set option ``$ tmux set-option <option> <value>``.
+        """Set option ``$ tmux set-option <option> <value>``.
 
         Parameters
         ----------
@@ -197,7 +204,7 @@ class Session(Obj, EnvironmentMixin):
         elif isinstance(value, bool) and not value:
             value = "off"
 
-        tmux_args: t.Tuple[t.Union[str, int], ...] = tuple()
+        tmux_args: t.Tuple[t.Union[str, int], ...] = ()
 
         if _global:
             tmux_args += ("-g",)
@@ -218,13 +225,10 @@ class Session(Obj, EnvironmentMixin):
         return self
 
     def show_options(
-        self, _global: t.Optional[bool] = False
+        self,
+        _global: t.Optional[bool] = False,
     ) -> t.Dict[str, t.Union[str, int]]:
-        """
-        Return a dict of options for the window.
-
-        For familiarity with tmux, the option ``option`` param forwards to pick
-        a single option, forwarding to :meth:`Session.show_option`.
+        """Return dict of options for the session.
 
         Parameters
         ----------
@@ -240,7 +244,7 @@ class Session(Obj, EnvironmentMixin):
         Uses ``_global`` for keyword name instead of ``global`` to avoid
         colliding with reserved keyword.
         """
-        tmux_args: t.Tuple[str, ...] = tuple()
+        tmux_args: t.Tuple[str, ...] = ()
 
         if _global:
             tmux_args += ("-g",)
@@ -260,9 +264,11 @@ class Session(Obj, EnvironmentMixin):
         return session_options
 
     def show_option(
-        self, option: str, _global: bool = False
+        self,
+        option: str,
+        _global: bool = False,
     ) -> t.Optional[t.Union[str, int, bool]]:
-        """Return a list of options for the window.
+        """Return option value for the target session.
 
         Parameters
         ----------
@@ -287,8 +293,7 @@ class Session(Obj, EnvironmentMixin):
 
         Test and return True/False for on/off string.
         """
-
-        tmux_args: t.Tuple[str, ...] = tuple()
+        tmux_args: t.Tuple[str, ...] = ()
 
         if _global:
             tmux_args += ("-g",)
@@ -303,7 +308,7 @@ class Session(Obj, EnvironmentMixin):
         if not len(cmd.stdout):
             return None
 
-        value_raw: t.List[str] = [item.split(" ") for item in cmd.stdout][0]
+        value_raw: t.List[str] = next(item.split(" ") for item in cmd.stdout)
 
         assert isinstance(value_raw[0], str)
         assert isinstance(value_raw[1], str)
@@ -315,8 +320,7 @@ class Session(Obj, EnvironmentMixin):
         return value
 
     def select_window(self, target_window: t.Union[str, int]) -> "Window":
-        """
-        Return :class:`Window` selected via ``$ tmux select-window``.
+        """Select window, return selected window.
 
         Parameters
         ----------
@@ -334,7 +338,6 @@ class Session(Obj, EnvironmentMixin):
 
             assure ``-l``, ``-n``, ``-p`` work.
         """
-
         # Note that we also provide the session ID here, since cmd()
         # will not automatically add it as there is already a '-t'
         # argument provided.
@@ -352,47 +355,123 @@ class Session(Obj, EnvironmentMixin):
     #
     @property
     def attached_window(self) -> "Window":
-        """
-        Return active :class:`Window` object.
-        """
-        active_windows = []
-        for window in self.windows:
-            # for now window_active is a unicode
-            if window.window_active == "1":
-                active_windows.append(window)
+        """Return active :class:`Window` object."""
+        active_windows = [
+            window for window in self.windows if window.window_active == "1"
+        ]
 
         if len(active_windows) == 1:
-            return list(active_windows)[0]
+            return next(iter(active_windows))
         elif len(active_windows) == 0:
-            raise exc.LibTmuxException("no active windows found")
+            raise exc.NoActiveWindow()
         else:
-            raise exc.LibTmuxException(
-                "multiple active windows found. %s" % active_windows
-            )
+            raise exc.MultipleActiveWindows(count=len(active_windows))
 
         if len(self._windows) == 0:
-            raise exc.LibTmuxException("No Windows")
+            raise exc.NoWindowsExist()
 
-    def attach_session(self) -> "Session":
-        """Return ``$ tmux attach-session`` aka alias: ``$ tmux attach``."""
-        proc = self.cmd("attach-session", "-t%s" % self.session_id)
+    def attach(
+        self,
+        _exit: t.Optional[bool] = None,
+        _flags: t.Optional[t.List[str]] = None,
+    ) -> "Session":
+        """Return ``$ tmux attach-session`` aka alias: ``$ tmux attach``.
+
+        Examples
+        --------
+        >>> session = server.new_session()
+
+        >>> session not in server.attached_sessions
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if _exit is not None and _exit:
+            flags += ("-x",)
+
+        if _flags is not None and isinstance(_flags, list):
+            flags += tuple(f'{",".join(_flags)}')
+
+        proc = self.cmd(
+            "attach-session",
+            *flags,
+        )
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+        self.refresh()
+
         return self
 
-    def kill_session(self) -> None:
-        """``$ tmux kill-session``."""
+    def kill(
+        self,
+        all_except: t.Optional[bool] = None,
+        clear: t.Optional[bool] = None,
+    ) -> None:
+        """Kill :class:`Session`, closes linked windows and detach all clients.
 
-        proc = self.cmd("kill-session", "-t%s" % self.session_id)
+        ``$ tmux kill-session``.
+
+        Parameters
+        ----------
+        all_except : bool, optional
+            Kill all sessions in server except this one.
+        clear : bool, optional
+            Clear alerts (bell, activity, or silence) in all windows.
+
+        Examples
+        --------
+        Kill a session:
+
+        >>> session_1 = server.new_session()
+
+        >>> session_1 in server.sessions
+        True
+
+        >>> session_1.kill()
+
+        >>> session_1 not in server.sessions
+        True
+
+        Kill all sessions except the current one:
+
+        >>> one_session_to_rule_them_all = server.new_session()
+
+        >>> other_sessions = server.new_session(
+        ...     ), server.new_session()
+
+        >>> all([w in server.sessions for w in other_sessions])
+        True
+
+        >>> one_session_to_rule_them_all.kill(all_except=True)
+
+        >>> all([w not in server.sessions for w in other_sessions])
+        True
+
+        >>> one_session_to_rule_them_all in server.sessions
+        True
+        """
+        flags: t.Tuple[str, ...] = ()
+
+        if all_except:
+            flags += ("-a",)
+
+        if clear:  # Clear alerts (bell, activity, or silence) in all windows
+            flags += ("-C",)
+
+        proc = self.cmd(
+            "kill-session",
+            *flags,
+        )
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+        return None
+
     def switch_client(self) -> "Session":
-        """
-        Switch client to this session.
+        """Switch client to session.
 
         Raises
         ------
@@ -406,8 +485,7 @@ class Session(Obj, EnvironmentMixin):
         return self
 
     def rename_session(self, new_name: str) -> "Session":
-        """
-        Rename session and return new :class:`Session` object.
+        """Rename session and return new :class:`Session` object.
 
         Parameters
         ----------
@@ -442,13 +520,12 @@ class Session(Obj, EnvironmentMixin):
         self,
         window_name: t.Optional[str] = None,
         start_directory: None = None,
-        attach: bool = True,
+        attach: bool = False,
         window_index: str = "",
         window_shell: t.Optional[str] = None,
         environment: t.Optional[t.Dict[str, str]] = None,
     ) -> "Window":
-        """
-        Return :class:`Window` from ``$ tmux new-window``.
+        """Create new window, returns new :class:`Window`.
 
         By default, this will make the window active. For the new window
         to be created and not set to current, pass in ``attach=False``.
@@ -472,11 +549,15 @@ class Session(Obj, EnvironmentMixin):
                 useful for long-running processes where the closing of the
                 window upon completion is desired.
 
+        .. versionchanged:: 0.28.0
+
+           ``attach`` default changed from ``True`` to ``False``.
+
         Returns
         -------
         :class:`Window`
         """
-        window_args: t.Tuple[str, ...] = tuple()
+        window_args: t.Tuple[str, ...] = ()
 
         if not attach:
             window_args += ("-d",)
@@ -485,8 +566,8 @@ class Session(Obj, EnvironmentMixin):
 
         if start_directory:
             # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
-            start_directory = os.path.expanduser(start_directory)
-            window_args += ("-c%s" % start_directory,)
+            start_directory = pathlib.Path(start_directory).expanduser()
+            window_args += (f"-c{start_directory}",)
 
         window_args += ("-F#{window_id}",)  # output
         if window_name is not None and isinstance(window_name, str):
@@ -494,8 +575,7 @@ class Session(Obj, EnvironmentMixin):
 
         window_args += (
             # empty string for window_index will use the first one available
-            "-t%s:%s"
-            % (self.session_id, window_index),
+            f"-t{self.session_id}:{window_index}",
         )
 
         if environment:
@@ -504,7 +584,7 @@ class Session(Obj, EnvironmentMixin):
                     window_args += (f"-e{k}={v}",)
             else:
                 logger.warning(
-                    "Cannot set up environment as tmux 3.0 or newer is required."
+                    "Environment flag ignored, requires tmux 3.0 or newer.",
                 )
 
         if window_shell:
@@ -518,15 +598,16 @@ class Session(Obj, EnvironmentMixin):
         window_output = cmd.stdout[0]
 
         window_formatters = dict(
-            zip(["window_id"], window_output.split(FORMAT_SEPARATOR))
+            zip(["window_id"], window_output.split(FORMAT_SEPARATOR)),
         )
 
         return Window.from_window_id(
-            server=self.server, window_id=window_formatters["window_id"]
+            server=self.server,
+            window_id=window_formatters["window_id"],
         )
 
     def kill_window(self, target_window: t.Optional[str] = None) -> None:
-        """Close a tmux window, and all panes inside it, ``$ tmux kill-window``
+        """Close a tmux window, and all panes inside it, ``$ tmux kill-window``.
 
         Kill the current window or the window at ``target-window``. removing it
         from any sessions to which it is linked.
@@ -536,7 +617,6 @@ class Session(Obj, EnvironmentMixin):
         target_window : str, optional
             window to kill
         """
-
         if target_window:
             if isinstance(target_window, int):
                 target = "-t%s:%d" % (self.window_name, target_window)
@@ -554,17 +634,19 @@ class Session(Obj, EnvironmentMixin):
     @property
     def attached_pane(self) -> t.Optional["Pane"]:
         """Return active :class:`Pane` object."""
-
         return self.attached_window.attached_pane
 
     #
     # Dunder
     #
     def __eq__(self, other: object) -> bool:
-        assert isinstance(other, Session)
-        return self.session_id == other.session_id
+        """Equal operator for :class:`Session` object."""
+        if isinstance(other, Session):
+            return self.session_id == other.session_id
+        return False
 
     def __repr__(self) -> str:
+        """Representation of :class:`Session` object."""
         return f"{self.__class__.__name__}({self.session_id} {self.session_name})"
 
     #
@@ -572,7 +654,7 @@ class Session(Obj, EnvironmentMixin):
     #
     @property
     def id(self) -> t.Optional[str]:
-        """Alias of :attr:`Session.session_id`
+        """Alias of :attr:`Session.session_id`.
 
         >>> session.id
         '$1'
@@ -584,7 +666,7 @@ class Session(Obj, EnvironmentMixin):
 
     @property
     def name(self) -> t.Optional[str]:
-        """Alias of :attr:`Session.session_name`
+        """Alias of :attr:`Session.session_name`.
 
         >>> session.name
         'libtmux_...'
@@ -597,49 +679,135 @@ class Session(Obj, EnvironmentMixin):
     #
     # Legacy: Redundant stuff we want to remove
     #
+    def attach_session(self) -> "Session":
+        """Return ``$ tmux attach-session`` aka alias: ``$ tmux attach``.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.attach()`.
+        """
+        warnings.warn(
+            "Session.attach_session() is deprecated in favor of Session.attach()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        proc = self.cmd("attach-session", "-t%s" % self.session_id)
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
+        return self
+
+    def kill_session(self) -> None:
+        """Destroy session.
+
+        Notes
+        -----
+        .. deprecated:: 0.30
+
+           Deprecated in favor of :meth:`.kill()`.
+        """
+        warnings.warn(
+            "Session.kill_session() is deprecated in favor of Session.kill()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        proc = self.cmd("kill-session", "-t%s" % self.session_id)
+
+        if proc.stderr:
+            raise exc.LibTmuxException(proc.stderr)
+
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
-        """
+        """Return key-based lookup. Deprecated by attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated by attribute lookup.e.g. ``session['session_name']`` is now
+           accessed via ``session.session_name``.
+
         """
-        warnings.warn("Session.get() is deprecated")
+        warnings.warn(
+            "Session.get() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
-        """
+        """Return item lookup by key. Deprecated in favor of attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated in favor of attributes. e.g. ``session['session_name']`` is now
+           accessed via ``session.session_name``.
+
         """
-        warnings.warn(f"Item lookups, e.g. session['{key}'] is deprecated")
+        warnings.warn(
+            f"Item lookups, e.g. session['{key}'] is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return getattr(self, key)
 
-    def get_by_id(self, id: str) -> t.Optional[Window]:
-        """
+    def get_by_id(self, session_id: str) -> t.Optional[Window]:
+        """Return window by id. Deprecated in favor of :meth:`.windows.get()`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.windows.get()`.
+
         """
-        warnings.warn("Session.get_by_id() is deprecated")
-        return self.windows.get(window_id=id, default=None)
+        warnings.warn(
+            "Session.get_by_id() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.windows.get(window_id=session_id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Window]:
-        """
+        """Filter through windows, return list of :class:`Window`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.windows.filter()`.
+
         """
-        warnings.warn("Session.where() is deprecated")
+        warnings.warn(
+            "Session.where() is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         try:
             return self.windows.filter(**kwargs)
         except IndexError:
             return []
 
     def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Window]:
-        """
+        """Filter through windows, return first :class:`Window`.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :meth:`.windows.get()`.
+
         """
-        warnings.warn("Session.find_where() is deprecated")
+        warnings.warn(
+            "Session.find_where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.windows.get(default=None, **kwargs)
 
     def _list_windows(self) -> t.List["WindowDict"]:
-        """
+        """Return list of windows (deprecated in favor of :attr:`.windows`).
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.windows`.
+
         """
-        warnings.warn("Session._list_windows() is deprecated")
+        warnings.warn(
+            "Session._list_windows() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return [w.__dict__ for w in self.windows]
 
     @property
@@ -647,23 +815,40 @@ class Session(Obj, EnvironmentMixin):
         """Property / alias to return :meth:`Session._list_windows`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.windows`.
+
         """
-        warnings.warn("Session._windows is deprecated")
+        warnings.warn(
+            "Session._windows is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self._list_windows()
 
     def list_windows(self) -> t.List["Window"]:
         """Return a list of :class:`Window` from the ``tmux(1)`` session.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.windows`.
+
         """
-        warnings.warn("Session.list_windows() is deprecated")
+        warnings.warn(
+            "Session.list_windows() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.windows
 
     @property
-    def children(self) -> QueryList["Window"]:  # type:ignore
-        """Was used by TmuxRelationalObject (but that's longer used in this class)
+    def children(self) -> QueryList["Window"]:
+        """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.windows`.
+
         """
-        warnings.warn("Session.children is deprecated")
+        warnings.warn(
+            "Session.children is deprecated", category=DeprecationWarning, stacklevel=2
+        )
         return self.windows
