@@ -1,3 +1,4 @@
+"""Tests for libtmux pytest plugin."""
 import textwrap
 
 import pytest
@@ -7,6 +8,7 @@ def test_plugin(
     pytester: pytest.Pytester,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
+    """Test libtmux pytest plugin."""
     # Initialize variables
     pytester.plugins = ["pytest_plugin"]
     pytester.makefile(
@@ -15,7 +17,7 @@ def test_plugin(
             """
 [pytest]
 addopts=-vv
-        """.strip()
+        """.strip(),
         ),
     )
     pytester.makeconftest(
@@ -29,8 +31,8 @@ def setup(
     request: pytest.FixtureRequest,
 ) -> None:
     pass
-    """
-        )
+    """,
+        ),
     )
     tests_path = pytester.path / "tests"
     files = {
@@ -47,13 +49,12 @@ def test_repo_git_remote_checkout(
 
     new_window = session.new_window(attach=False, window_name="my window name")
     assert new_window.window_name == "my window name"
-        """
-        )
+        """,
+        ),
     }
-    first_test_key = list(files.keys())[0]
+    first_test_key = next(iter(files.keys()))
     first_test_filename = str(tests_path / first_test_key)
 
-    # Setup: Files
     tests_path.mkdir()
     for file_name, text in files.items():
         test_file = tests_path / file_name
