@@ -8,7 +8,8 @@ import pytest
 
 from libtmux import exc
 from libtmux._internal.query_list import ObjectDoesNotExist
-from libtmux.common import has_gte_version, has_lt_version
+from libtmux.common import has_gte_version, has_lt_version, has_version
+from libtmux.constants import ResizeAdjustmentDirection
 from libtmux.pane import Pane
 from libtmux.server import Server
 from libtmux.session import Session
@@ -18,6 +19,7 @@ logger = logging.getLogger(__name__)
 
 
 def test_select_window(session: Session) -> None:
+    """Test Window.select_window()."""
     window_count = len(session.windows)
     # to do, get option for   base-index from tmux
     # for now however, let's get the index from the first window.
@@ -43,7 +45,8 @@ def test_select_window(session: Session) -> None:
     assert len(session.windows) == 2
 
 
-def test_zfresh_window_data(session: Session) -> None:
+def test_fresh_window_data(session: Session) -> None:
+    """Verify window data is fresh."""
     attached_window = session.attached_window
     assert attached_window is not None
     pane_base_idx = attached_window.show_window_option("pane-base-index", g=True)
@@ -96,6 +99,7 @@ def test_zfresh_window_data(session: Session) -> None:
 
 
 def test_newest_pane_data(session: Session) -> None:
+    """Test window.panes has fresh data."""
     window = session.new_window(window_name="test", attach=True)
     assert isinstance(window, Window)
     assert len(window.panes) == 1
@@ -110,7 +114,6 @@ def test_newest_pane_data(session: Session) -> None:
 
 def test_attached_pane(session: Session) -> None:
     """Window.attached_window returns active Pane."""
-
     window = session.attached_window  # current window
     assert isinstance(window.attached_pane, Pane)
 
@@ -168,14 +171,64 @@ def test_split_window_horizontal(session: Session) -> None:
     assert float(first_pane.pane_width) <= ((float(window.window_width) + 1) / 2)
 
 
+def test_split_percentage(session: Session) -> None:
+    """Test deprecated percent param."""
+    window = session.new_window(window_name="split window size")
+    window.resize(height=100, width=100)
+    window_height_before = (
+        int(window.window_height) if isinstance(window.window_height, str) else 0
+    )
+    if has_version("3.4"):
+        pytest.skip(
+            "tmux 3.4 has a split-window bug."
+            + " See https://github.com/tmux/tmux/pull/3840."
+        )
+    with pytest.warns(match="Deprecated in favor of size.*"):
+        pane = window.split_window(percent=10)
+        assert pane.pane_height == str(int(window_height_before * 0.1))
+
+
+def test_split_window_size(session: Session) -> None:
+    """Window.split_window() respects size."""
+    window = session.new_window(window_name="split window size")
+    window.resize(height=100, width=100)
+
+    if has_gte_version("3.1"):
+        pane = window.split_window(size=10)
+        assert pane.pane_height == "10"
+
+        pane = window.split_window(vertical=False, size=10)
+        assert pane.pane_width == "10"
+
+        pane = window.split_window(size="10%")
+        assert pane.pane_height == "8"
+
+        pane = window.split_window(vertical=False, size="10%")
+        assert pane.pane_width == "8"
+    else:
+        window_height_before = (
+            int(window.window_height) if isinstance(window.window_height, str) else 0
+        )
+        window_width_before = (
+            int(window.window_width) if isinstance(window.window_width, str) else 0
+        )
+        pane = window.split_window(size="10%")
+        assert pane.pane_height == str(int(window_height_before * 0.1))
+
+        pane = window.split_window(vertical=False, size="10%")
+        assert pane.pane_width == str(int(window_width_before * 0.1))
+
+
 @pytest.mark.parametrize(
     "window_name_before,window_name_after",
     [("test", "ha ha ha fjewlkjflwef"), ("test", "hello \\ wazzup 0")],
 )
 def test_window_rename(
-    session: Session, window_name_before: str, window_name_after: str
+    session: Session,
+    window_name_before: str,
+    window_name_after: str,
 ) -> None:
-    """Window.rename_window()."""
+    """Test Window.rename_window()."""
     window_name_before = "test"
     window_name_after = "ha ha ha fjewlkjflwef"
 
@@ -197,13 +250,14 @@ def test_window_rename(
 
 
 def test_kill_window(session: Session) -> None:
+    """Test window.kill_window() kills window."""
     session.new_window()
     # create a second window to not kick out the client.
     # there is another way to do this via options too.
 
     w = session.attached_window
 
-    w.window_id
+    assert w.window_id is not None
 
     w.kill_window()
     with pytest.raises(ObjectDoesNotExist):
@@ -235,6 +289,7 @@ def test_set_show_window_options(session: Session) -> None:
 
 
 def test_empty_window_option_returns_None(session: Session) -> None:
+    """Verify unset window option returns None."""
     window = session.new_window(window_name="test_window")
     assert window.show_window_option("alternate-screen") is None
 
@@ -280,7 +335,6 @@ def test_set_window_option_ambiguous(session: Session) -> None:
 
 def test_set_window_option_invalid(session: Session) -> None:
     """Window.set_window_option raises ValueError for invalid option key."""
-
     window = session.new_window(window_name="test_window")
 
     if has_gte_version("2.4"):
@@ -292,8 +346,7 @@ def test_set_window_option_invalid(session: Session) -> None:
 
 
 def test_move_window(session: Session) -> None:
-    """Window.move_window results in changed index"""
-
+    """Window.move_window results in changed index."""
     window = session.new_window(window_name="test_window")
     assert window.window_index is not None
     new_index = str(int(window.window_index) + 1)
@@ -302,6 +355,7 @@ def test_move_window(session: Session) -> None:
 
 
 def test_move_window_to_other_session(server: Server, session: Session) -> None:
+    """Window.move_window to other session."""
     window = session.new_window(window_name="test_window")
     new_session = server.new_session("test_move_window")
     window.move_window(session=new_session.session_id)
@@ -311,16 +365,17 @@ def test_move_window_to_other_session(server: Server, session: Session) -> None:
 
 
 def test_select_layout_accepts_no_arg(server: Server, session: Session) -> None:
-    """tmux allows select-layout with no arguments, so let's allow it here."""
-
+    """Tmux allows select-layout with no arguments, so let's allow it here."""
     window = session.new_window(window_name="test_window")
     window.select_layout()
 
 
 @pytest.mark.skipif(
-    has_lt_version("3.2"), reason="needs filter introduced in tmux >= 3.2"
+    has_lt_version("3.2"),
+    reason="needs filter introduced in tmux >= 3.2",
 )
 def test_empty_window_name(session: Session) -> None:
+    """New windows can be created with empty string for window name."""
     session.set_option("automatic-rename", "off")
     window = session.new_window(window_name="''", attach=True)
 
@@ -353,6 +408,7 @@ def test_split_window_with_environment(
     session: Session,
     environment: t.Dict[str, str],
 ) -> None:
+    """Verify splitting window with environment variables."""
     env = shutil.which("env")
     assert env is not None, "Cannot find usable `env` in Path."
 
@@ -377,6 +433,7 @@ def test_split_window_with_environment_logs_warning_for_old_tmux(
     session: Session,
     caplog: pytest.LogCaptureFixture,
 ) -> None:
+    """Verify splitting window with environment variables warns if tmux too old."""
     env = shutil.which("env")
     assert env is not None, "Cannot find usable `env` in Path."
 
@@ -387,5 +444,85 @@ def test_split_window_with_environment_logs_warning_for_old_tmux(
     )
 
     assert any(
-        "Cannot set up environment" in record.msg for record in caplog.records
+        "Environment flag ignored" in record.msg for record in caplog.records
     ), "Warning missing"
+
+
+@pytest.mark.skipif(
+    has_lt_version("2.9"),
+    reason="resize-window only exists in tmux 2.9+",
+)
+def test_resize(
+    session: Session,
+) -> None:
+    """Verify resizing window."""
+    session.cmd("detach-client", "-s")
+
+    window = session.attached_window
+    window_height_adjustment = 10
+
+    assert window.window_height is not None
+    assert window.window_width is not None
+
+    #
+    # Manual resizing
+    #
+
+    # Manual: Height
+    window_height_before = int(window.window_height)
+    window.resize(
+        height=10,
+    )
+    assert int(window.window_height) == 10
+
+    # Manual: Width
+    window.resize(
+        width=10,
+    )
+    assert int(window.window_width) == 10
+
+    #
+    # Adjustments
+    #
+
+    # Adjustment: Down
+    window_height_before = int(window.window_height)
+    window.resize(
+        adjustment_direction=ResizeAdjustmentDirection.Down,
+        adjustment=window_height_adjustment * 2,
+    )
+    assert window_height_before + (window_height_adjustment * 2) == int(
+        window.window_height
+    )
+
+    # Adjustment: Up
+    window_height_before = int(window.window_height)
+    window.resize(
+        adjustment_direction=ResizeAdjustmentDirection.Up,
+        adjustment=window_height_adjustment,
+    )
+    assert window_height_before - window_height_adjustment == int(window.window_height)
+
+    #
+    # Shrink and expand
+    #
+    window.resize(height=50)
+
+    # Shrink
+    window_height_before = int(window.window_height)
+    window.resize(
+        shrink=True,
+    )
+    window_height_shrunk = int(window.window_height)
+    assert window_height_before > window_height_shrunk
+
+    assert window
+
+    # Expand
+    window.resize(height=2)
+    window_height_before = int(window.window_height)
+    window.resize(
+        expand=True,
+    )
+    window_height_expanded = int(window.window_height)
+    assert window_height_before < window_height_expanded
